package net.sf.doolin.template.velocity;

import java.io.InputStream;
import java.util.Locale;

import net.sf.doolin.util.LocaleUtils;

import org.apache.commons.collections.ExtendedProperties;
import org.apache.velocity.exception.ResourceNotFoundException;
import org.apache.velocity.runtime.resource.Resource;
import org.apache.velocity.runtime.resource.loader.ResourceLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author Damien Coraboeuf
 */
public class VelocityResourceLoader extends ResourceLoader {

	/**
	 * Logger
	 */
	private final static Logger log = LoggerFactory
			.getLogger(VelocityResourceLoader.class);

	/**
	 * Defaults to return 0
	 */
	@Override
	public long getLastModified(Resource resource) {
		return 0;
	}

	/**
	 * Loads the resource from classpath
	 */
	@Override
	public InputStream getResourceStream(String name)
			throws ResourceNotFoundException {
		log.debug("Loading template from classpath : " + name);
		// Checks the name
		if (name == null || name.length() == 0) {
			throw new ResourceNotFoundException("No template name provided");
		} else {
			try {
				InputStream result = LocaleUtils.getResourceAsStream(name,
						Locale.getDefault());
				if (result == null) {
					throw new ResourceNotFoundException(
							"Cannot find template at " + name);
				}
				return result;
			} catch (Exception fnfe) {
				throw new ResourceNotFoundException(fnfe.getMessage());
			}
		}
	}

	/**
	 * Nothing to initialize
	 */
	@Override
	public void init(ExtendedProperties configuration) {
	}

	/**
	 * Defaults to return false.
	 */
	@Override
	public boolean isSourceModified(Resource resource) {
		return false;
	}
}
